package sample.sdt.barcode;

import sdt.brc.android.BarcodeReader;
import sdt.brc.android.BarcodeReaderResult;
import sdt.brc.android.BarcodeReaderUtil;
import sdt.brc.android.BarcodeScanDialog;
import sdt.brc.android.OnRecognitionListener;


import android.app.Activity;
import android.graphics.Bitmap;
import android.graphics.YuvImage;
import android.os.Bundle;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import java.util.List;

public class SDTBarcodeSampleActivity extends Activity {

    /** Barcode Read  Dialog */
    BarcodeScanDialog mCamDlg = null;

    /** UI */
    Button mShowCamBut = null;


    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);

        mShowCamBut = (Button)findViewById(R.id.readBarcode);
        if(mShowCamBut != null) {
            mShowCamBut.setOnClickListener(new OnClickListener() {

                public void onClick(View v) {
                    showCameraDlg();
                }
            });
        }
    }
    @Override
    protected void onStart() {
        super.onStart();
    }

    @Override
    protected void onStop() {
        hideCameraDialog();
        super.onStop();
    }

    protected void hideCameraDialog() {
        //It is important to hide Scan preview dialog in order to release locked Camera resource.
        if( mCamDlg != null ) {
            mCamDlg.hide();
	        mCamDlg.dismiss();
	        mCamDlg = null;
        }
    }

    protected void showCameraDlg() {

        mCamDlg = new BarcodeScanDialog(this, "License Key");

        if(mCamDlg != null) {

            mCamDlg.setBarcodeTypes(BarcodeReader.SDTBARCODE_ALL_1D);
            mCamDlg.showActiveArea(true);

            mCamDlg.setRecognitionListener(new OnRecognitionListener() {

                public void onRecognitionResults(List results, YuvImage srcImage) {
                    // Populate results
                    LinearLayout resultsLayout = (LinearLayout)findViewById(R.id.resultsValues);
                    if(resultsLayout != null) {
                        resultsLayout.removeAllViews();

                        for (BarcodeReaderResult barcodeReaderResult : (List<BarcodeReaderResult>)results) {
                            String value =  "[" + barcodeReaderResult.getTypeName() + "]" + barcodeReaderResult.getValue() + "\n";
                            TextView tv = new TextView(getApplicationContext());
                            if(tv != null) {
                                tv.setText(value);
                                resultsLayout.addView(tv);
                            }

                        }

                    }

                    //Hide scan dialog
                    mCamDlg.hide();

                    //Show the image
                    if(srcImage != null) {
                        ImageView iv = (ImageView)findViewById(R.id.resultsImage);
                        if(iv != null) {
                            Bitmap bm = BarcodeReaderUtil.decodeImageToBitmap(srcImage);
                            iv.setImageBitmap(bm);
                        }
                    }

                }
            });

            mCamDlg.show();
        }
    }

}